@@ -577,9 +577,9 @@ static bool FindTagInTableDir(FallibleTArray<uint8_t>& table,
 bool
 MacOSFontEntry::HasFontTable(uint32_t aTableTag)
 {
-#if(0)
     nsAutoreleasePool localPool;
 
+#if(0)
     CGFontRef fontRef = GetFontRef();
     if (!fontRef) {
         return false;
@@ -1334,6 +1334,7 @@ gfxMacPlatformFontList::MakePlatformFont(const gfxProxyFontEntry *aProxyEntry,
 #if(1)
     // ATSFontRef version
     OSStatus err;
+    nsAutoreleasePool lazy;
 
     NS_ASSERTION(aFontData, "MakePlatformFont called with null data");
 
@@ -1394,6 +1395,17 @@ gfxMacPlatformFontList::MakePlatformFont(const gfxProxyFontEntry *aProxyEntry,
         NSString *psname = NULL;
         err = ::ATSFontGetPostScriptName(fontRef, kATSOptionFlagsDefault, (CFStringRef*) (&psname));
         if (err == noErr) {
+                // Check the font blacklist (TenFourFox issue 261).
+                if ([psname isEqualToString:@"prisjakticons"]) {
+                        fprintf(stderr,
+"Warning: TenFourFox rejected ATSUI-incompatible web font %s.\n",
+                                [psname UTF8String]);
+                        [psname release];
+                        ::ATSFontDeactivate(containerRef, NULL,
+                                kATSOptionFlagsDefault);
+                        return nullptr;
+                }
+
             [psname release];
         } else {
 #ifdef DEBUG
